==> istio-model-v1alpha3-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterEnvoyConfigObjectMatchBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EnvoyFilterEnvoyConfigObjectMatchBuilder extends EnvoyFilterEnvoyConfigObjectMatchFluentImpl<EnvoyFilterEnvoyConfigObjectMatchBuilder> implements VisitableBuilder<EnvoyFilterEnvoyConfigObjectMatch,EnvoyFilterEnvoyConfigObjectMatchBuilder>{
  public EnvoyFilterEnvoyConfigObjectMatchBuilder() {
    this(false);
  }
  public EnvoyFilterEnvoyConfigObjectMatchBuilder(Boolean validationEnabled) {
    this(new EnvoyFilterEnvoyConfigObjectMatch(), validationEnabled);
  }
  public EnvoyFilterEnvoyConfigObjectMatchBuilder(EnvoyFilterEnvoyConfigObjectMatchFluent<?> fluent) {
    this(fluent, false);
  }
  public EnvoyFilterEnvoyConfigObjectMatchBuilder(EnvoyFilterEnvoyConfigObjectMatchFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EnvoyFilterEnvoyConfigObjectMatch(), validationEnabled);
  }
  public EnvoyFilterEnvoyConfigObjectMatchBuilder(EnvoyFilterEnvoyConfigObjectMatchFluent<?> fluent,EnvoyFilterEnvoyConfigObjectMatch instance) {
    this(fluent, instance, false);
  }
  public EnvoyFilterEnvoyConfigObjectMatchBuilder(EnvoyFilterEnvoyConfigObjectMatchFluent<?> fluent,EnvoyFilterEnvoyConfigObjectMatch instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withObjectTypes(instance.getObjectTypes());
      fluent.withContext(instance.getContext());
      fluent.withProxy(instance.getProxy());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EnvoyFilterEnvoyConfigObjectMatchBuilder(EnvoyFilterEnvoyConfigObjectMatch instance) {
    this(instance,false);
  }
  public EnvoyFilterEnvoyConfigObjectMatchBuilder(EnvoyFilterEnvoyConfigObjectMatch instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withObjectTypes(instance.getObjectTypes());
      this.withContext(instance.getContext());
      this.withProxy(instance.getProxy());
    }
    this.validationEnabled = validationEnabled; 
  }
  EnvoyFilterEnvoyConfigObjectMatchFluent<?> fluent;
  Boolean validationEnabled;
  public EnvoyFilterEnvoyConfigObjectMatch build() {
    EnvoyFilterEnvoyConfigObjectMatch buildable = new EnvoyFilterEnvoyConfigObjectMatch(fluent.getObjectTypes(),fluent.getContext(),fluent.getProxy());
    return buildable;
  }
  
}

==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterEnvoyConfigObjectMatchBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EnvoyFilterEnvoyConfigObjectMatchBuilder extends EnvoyFilterEnvoyConfigObjectMatchFluent<EnvoyFilterEnvoyConfigObjectMatchBuilder> implements VisitableBuilder<EnvoyFilterEnvoyConfigObjectMatch,EnvoyFilterEnvoyConfigObjectMatchBuilder>{
  public EnvoyFilterEnvoyConfigObjectMatchBuilder() {
    this(false);
  }
  public EnvoyFilterEnvoyConfigObjectMatchBuilder(Boolean validationEnabled) {
    this(new EnvoyFilterEnvoyConfigObjectMatch(), validationEnabled);
  }
  public EnvoyFilterEnvoyConfigObjectMatchBuilder(EnvoyFilterEnvoyConfigObjectMatchFluent<?> fluent) {
    this(fluent, false);
  }
  public EnvoyFilterEnvoyConfigObjectMatchBuilder(EnvoyFilterEnvoyConfigObjectMatchFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EnvoyFilterEnvoyConfigObjectMatch(), validationEnabled);
  }
  public EnvoyFilterEnvoyConfigObjectMatchBuilder(EnvoyFilterEnvoyConfigObjectMatchFluent<?> fluent,EnvoyFilterEnvoyConfigObjectMatch instance) {
    this(fluent, instance, false);
  }
  public EnvoyFilterEnvoyConfigObjectMatchBuilder(EnvoyFilterEnvoyConfigObjectMatchFluent<?> fluent,EnvoyFilterEnvoyConfigObjectMatch instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new EnvoyFilterEnvoyConfigObjectMatch());

    if (instance != null) {
      fluent.withObjectTypes(instance.getObjectTypes());
      fluent.withContext(instance.getContext());
      fluent.withProxy(instance.getProxy());
      fluent.withObjectTypes(instance.getObjectTypes());
      fluent.withContext(instance.getContext());
      fluent.withProxy(instance.getProxy());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EnvoyFilterEnvoyConfigObjectMatchBuilder(EnvoyFilterEnvoyConfigObjectMatch instance) {
    this(instance,false);
  }
  public EnvoyFilterEnvoyConfigObjectMatchBuilder(EnvoyFilterEnvoyConfigObjectMatch instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new EnvoyFilterEnvoyConfigObjectMatch());

    if (instance != null) {
      this.withObjectTypes(instance.getObjectTypes());
      this.withContext(instance.getContext());
      this.withProxy(instance.getProxy());
      this.withObjectTypes(instance.getObjectTypes());
      this.withContext(instance.getContext());
      this.withProxy(instance.getProxy());
    }
    this.validationEnabled = validationEnabled; 
  }
  EnvoyFilterEnvoyConfigObjectMatchFluent<?> fluent;
  Boolean validationEnabled;
  public EnvoyFilterEnvoyConfigObjectMatch build() {
    EnvoyFilterEnvoyConfigObjectMatch buildable = new EnvoyFilterEnvoyConfigObjectMatch(fluent.buildObjectTypes(),fluent.getContext(),fluent.buildProxy());
    return buildable;
  }
  
}
